@@ -26,7 +26,7 @@
 #include "ui_parameteranimator.h"
 #include "view.h"
 
-#include <kicon.h>
+#include <QIcon>
 #include <QTimer>
 
 #include <assert.h>
@@ -71,25 +71,25 @@ ParameterAnimator::ParameterAnimator( QWidget * parent, Function * function )
 		m_widget->warningLabel->hide();
 	
 	m_timer = new QTimer( this );
-	connect( m_timer, SIGNAL(timeout()), this, SLOT(step()) );
+	connect(m_timer, &QTimer::timeout, this, &ParameterAnimator::step);
 	
-	m_widget->gotoInitial->setIcon( KIcon( "go-first" ) );
-	m_widget->gotoFinal->setIcon( KIcon( "go-last" ) );
-	m_widget->stepBackwards->setIcon( KIcon( "go-previous" ) );
-	m_widget->stepForwards->setIcon( KIcon( "go-next" ) );
-	m_widget->pause->setIcon( KIcon( "media-playback-pause" ) );
+	m_widget->gotoInitial->setIcon( QIcon::fromTheme( "go-first" ) );
+	m_widget->gotoFinal->setIcon( QIcon::fromTheme( "go-last" ) );
+	m_widget->stepBackwards->setIcon( QIcon::fromTheme( "go-previous" ) );
+	m_widget->stepForwards->setIcon( QIcon::fromTheme( "go-next" ) );
+	m_widget->pause->setIcon( QIcon::fromTheme( "media-playback-pause" ) );
 	
-	connect( m_widget->gotoInitial, SIGNAL(clicked()), this, SLOT(gotoInitial()) );
-	connect( m_widget->gotoFinal, SIGNAL(clicked()), this, SLOT(gotoFinal()) );
-	connect( m_widget->stepBackwards, SIGNAL(toggled(bool)), this, SLOT(stepBackwards(bool)) );
-	connect( m_widget->stepForwards, SIGNAL(toggled(bool)), this, SLOT(stepForwards(bool)) );
-	connect( m_widget->pause, SIGNAL(clicked()), this, SLOT(pause()) );
-	connect( m_widget->speed, SIGNAL(valueChanged(int)), this, SLOT(updateSpeed()) );
+	connect(m_widget->gotoInitial, &QToolButton::clicked, this, &ParameterAnimator::gotoInitial);
+	connect(m_widget->gotoFinal, &QToolButton::clicked, this, &ParameterAnimator::gotoFinal);
+	connect(m_widget->stepBackwards, &QToolButton::toggled, this, &ParameterAnimator::stepBackwards);
+	connect(m_widget->stepForwards, &QToolButton::toggled, this, &ParameterAnimator::stepForwards);
+	connect(m_widget->pause, &QToolButton::clicked, this, &ParameterAnimator::pause);
+	connect(m_widget->speed, &QSlider::valueChanged, this, &ParameterAnimator::updateSpeed);
 	
 	updateUI();
 	updateFunctionParameter();
 	
-	connect( this, SIGNAL(finished()), this, SLOT(deleteLater()) );
+	connect(this, &ParameterAnimator::finished, this, &ParameterAnimator::deleteLater);
 }
 
 
@@ -246,5 +246,3 @@ void ParameterAnimator::stopStepping()
 	updateUI();
 }
 //END class ParameterAnimator
-
-#include "parameteranimator.moc"
